/*
 *	Copyright (C) 2002, Giovanni Di Stasi	giovannidistasi@libero.it
 *
 *	This file is part of 'starzanet'
 *
 *	See the file called "LICENSE" for license information.
 */

package gdistasi.StarzaNet.client;

import gdistasi.StarzaNet.server.*;
import gdistasi.StarzaNet.client.*;
import gdistasi.StarzaNet.client.comandi.*;
import gdistasi.StarzaNet.client.bacheca.*;
import gdistasi.StarzaNet.server.gestione.*;

import java.io.IOException;
import javax.swing.JOptionPane;


public class Connessione implements Runnable {
    protected SocketClient socket;
    protected GestoreComandiClient gestoreComandi;
    protected String user;
    protected Thread threadTimeout;
    protected char[] pass;
    protected MainWin win;
    protected boolean stop;
    protected boolean connesso;
    protected int connessi;
    protected DatiUtente datiConnessione;
    protected Bacheca bacheca;

    int cont=0;

    public Connessione(){ //introdotta per ConnessioneTestuale...
	
    }


    public Connessione(String user, char[] pass){
	stop=false;
	win=new MainWin(this,new String("StarzaNet - "));
	//win.show();
	datiConnessione=new DatiUtente();
	threadTimeout=new Thread(this);
	gestoreComandi=new GestoreComandiClient(win,win,this);
	connesso=false;
	setUser(user);
	setPass(pass);

	try {
	    socket=new SocketClient(new java.net.Socket(Environment.SERVER,Environment.porta),win);
	    autentica();
	    threadTimeout.start();
	} catch(IOException e){
	    System.out.println(e);
	    mostraErrore(e.getMessage());
	    System.exit(1);
	}
	
	bacheca=new Bacheca(gestoreComandi,socket);
	gestoreComandi.setBacheca(bacheca);
	win.show();
	premutoBacheca();

	//System.out.println("BACHECA"+gestoreComandi.getBacheca());

    }

    public void setUser(String user){
	this.user=user;
    }

    public void setPass(char[] pass){
	this.pass=pass;
    }

    public void mostraErrore(String err) {
	JOptionPane.showMessageDialog(null,err,"errore",JOptionPane.ERROR_MESSAGE);

    }

    public void run(){
	int count=0;
	aggiorna();
	try {
	    while (!stop){
		
		count++;			
		aggiorna();
		if (count==2) {
		    
		    gestoreComandi.eseguiComando(
		    new ComandoTimeout());
		    
		    count=0;
		}
		Thread.sleep(1000*25);
	    }
	} catch (java.lang.InterruptedException e) {
	    System.exit(3);
	}
    }

    protected void autentica() throws IOException {
	String ric;

	gestoreComandi.setSocket(socket);

	if (!leggiBenvenuto()) throw new IOException(
	     "Sulla macchina di destinazione e in esecuzione il server?");

	socket.writeLine(Environment.VERSION);

	if (socket.readInt()!=Environment.Version_Success) {
	    throw new IOException(
	     "Versione diversa! Aggiornare starzaClient");
	    }

	ric=socket.readLineAndLog();
	if (!ric.equals(Login.msgUser)) throw new IOException("err. in msgUser");
	socket.writeLineAndLog(user);
	ric=socket.readLineAndLog();
	if (!ric.equals(Login.msgPass)) throw new IOException("err. in msgPass"); 
	socket.writeLine(pass);
	cancellaPassDaMemoria(pass);
	ric=socket.readLineAndLog();
	if (!ric.equals(Login.loginCorretto)) throw new IOException("Login non corretto. Controllare user e password!");
	
    };


    protected void cancellaPassDaMemoria(char[] pass){
	for (int i=0; i<pass.length; i++)
	    pass[i]=0;
    }

    protected boolean leggiBenvenuto() throws ConnessioneCaduta {
	boolean ris=false;
	if (socket.readLineAndLog().equals(Login.benvenuto)) ris=true;
	return ris;
    }

    public void premutoDisconnetti(){
	Comando c=new ComandoDisconnetti();
	if (gestoreComandi.eseguiComando(c)==0){
	    //connesso=false;
	    //win.setConnesso(false);
	}
	aggiorna();
    }

    public void premutoPassword(){
	FinPassword finPass=new FinPassword(this);
    }

    public void cambiaPass(String vecchia, String nuova){
	ComandoCambiaPassword comando=new ComandoCambiaPassword(vecchia,nuova);
	gestoreComandi.eseguiComando(comando);
    }

    public void premutoBacheca() {
	bacheca.visualizza();
    }
    
    public void premutoConnetti(){
	Comando c=new ComandoConnetti();
	
	if (gestoreComandi.eseguiComando(c)==0) {
	    //connesso=true;
	    //win.setConnesso(true);
	}
	aggiorna();
	    
    }

    public void aggiorna(){
	ComandoConnessi con=new ComandoConnessi();

    	gestoreComandi.eseguiComando(con);
	win.setConnessi(con.getConnessi());
	setConnesso(con.isConnesso());

	Comando c=null;

	if (connesso){
	    c=new ComandoDati(datiConnessione);
	    //System.out.println("TEAHTEAH"+(cont++));
	    gestoreComandi.eseguiComando(c);
	}
    }

    public void setConnesso(boolean connesso){
	this.connesso=connesso;
	win.setConnesso(connesso);
    }

    public void setConnessi(int connessi){
	this.connessi=connessi;
	//	win.setConnessi(connessi);
    }

    public void premutoRiepilogo(){
	Comando c;
	// System.out.println("SHOW1");
	c=new ComandoProspetto();
	gestoreComandi.eseguiComando(c);
    }

    public void exitMainWin(){
	Comando c=new ComandoDisconnetti();
	gestoreComandi.eseguiComando(c);
	System.exit(0);
    }
}

interface LogConnessione {
    public void write(String s);
}

