/*
 *	Copyright (C) 2002, Giovanni Di Stasi	giovannidistasi@libero.it
 *
 *	This file is part of 'starzanet'
 *
 *	See the file called "LICENSE" for license information.
 */

package gdistasi.StarzaNet.server;

import gdistasi.StarzaNet.server.*;
import gdistasi.StarzaNet.server.telefono.*;
import gdistasi.StarzaNet.server.bacheca.Bacheca;
import gdistasi.StarzaNet.server.comandi.*;

import gnu.getopt.*;
import java.net.*;
import java.io.*;
import java.util.*;
import javax.xml.parsers.*;
import org.xml.sax.*;
import java.util.logging.*;

public class Main {
    GestoreComandi gestoreComandi;
    Connessione connessione;
    BestConnessione internet;
    ConnessioneInternet conn1,conn2;
    Bacheca bacheca;
    LettoreConf lettoreConf;
    ServerSocket server;
    Socket socket;
    ArrayList connessioni;
    Firewall firewall;
    Tel tel;
    Logger log;


    public Main() throws Exception{
	log=Environment.getLogger();
    }


    public void start(String[] arg) throws Exception {
	
	parseLineaDiComando(arg);
	
	
	
	leggiFile(true);

	internet = new BestConnessione(connessioni);

	bacheca=new Bacheca();	    
	connessione=new Connessione(internet,firewall,tel);
	

	

	
	try {
	    lettoreConf=new LettoreConf(Environment.getFileUtenti(),"SHA");
	} catch (java.security.NoSuchAlgorithmException e){
	    System.err.println(e);
	} catch (IOException e){
	    log.severe(e.getMessage());
	    System.exit(1);
	}

	
	gestoreComandi=new GestoreComandi(connessione,bacheca,lettoreConf);
	
	try {
	    server=new ServerSocket(Environment.porta,5);
	} catch (BindException e){
	    log.log(Level.SEVERE,"E' gi in esecuzione starzanet?",e);
	    System.err.println(e.getMessage());
	    System.err.println("E' gia in esecuzione starzanet?");
	    System.exit(1);
	}

	attendiConnessioni();

    }

    public void parseLineaDiComando(String[] args){
	Getopt g=new Getopt("starzanet",args,"lq:d:");

	int c;
	String arg;
	while ((c = g.getopt()) != -1){
	    switch(c){
	    case 'l':
		Environment.SQ=true;
		//System.out.println(g.getOptarg());
		break;
	    case 'd':
		setFileConf(g.getOptarg());
		break;

	    case 'q':
		Environment.debug=Integer.parseInt(g.getOptarg());
		break;

	    case '?':
		break; // getopt() already printed an error
    
		//
	    default:
		System.out.print("getopt() returned " + c + "\n");
	    }
	    
	}
	
	
    }

    public void setFileConf(String str){
	File file= new File(str);
	if (!file.exists()){
	    log.severe("Il file "+str+" non esiste");
	    System.exit(1);
	} 
	if (!file.canRead()){
	    log.severe("Non posso leggere "+str);
	    System.exit(1);
	}  
	
	Environment.dirConf=file.getParent()+file.separator;
    }

    public void controllaFile(boolean b){
	File file=new File(Environment.directory);
	
	    if (!file.canRead()){
		log.severe("Non posso leggere "+ Environment.directory);
		System.exit(1);
	    }
	    
	    if (b)
		if (!file.canWrite()){
		    log.severe("Non posso scrivere "+ Environment.directory);
		    System.exit(1);
		}
    }


    public void leggiFile(boolean b) {
	ErrorHandlerMy errorHandler=new ErrorHandlerMy(Environment.getLogger());
	File file;

	try {
	    Conf conf=new Conf(Environment.getFileConf(),errorHandler);
	    Environment.directory=conf.getDirVar();

	    controllaFile(b);

	    Environment.tariffaParagone=conf.getTariffaParagone();

	    connessioni= conf.getConnessioni();
	    firewall = conf.getFirewall();
	    tel = conf.getTel();
	    
	    


	} catch (ParserConfigurationException e){
	    System.err.println(e);
	    System.exit(3);
	} catch (SAXException e){
	    System.err.println(e);
	    System.exit(3);
	} catch (IOException e){
	    System.err.println(e);
	    System.exit(3);
	}

    }



    public void attendiConnessioni(){ 
	while(true)
	    try {
		socket=server.accept();
		Environment.getLogger().log(Level.INFO,
			"Connessione entrante da: "+socket.getInetAddress().toString());
		new Login(socket,gestoreComandi,lettoreConf);
	    } catch (IOException e){ 
		System.err.println(""+e); 
	    }

    }


    
     public static void main(String[] arg) throws Exception {
	Main m=new Main();
	m.start(arg);
    }

  
}




