/*
 *	Copyright (C) 2002, Giovanni Di Stasi	giovannidistasi@libero.it
 *
 *	This file is part of 'starzanet'
 *
 *	See the file called "LICENSE" for license information.
 */

package gdistasi.StarzaNet.server.gestione;


import java.util.*;

public class Selezionatore {
    ArrayList criteri;
    Calendar calendario;

    public static final int TUTTI=-10;
    public static final int MESE_CORRENTE=0;
    public static final int MESE_PREC=-1;
    public static final int MESE_PREC2=-2;
    public static final int MESE_PREC3=-3;
    


    public Selezionatore(){
	criteri=new ArrayList(4);
	calendario=new GregorianCalendar();
    }

    public void clearCriteri(){
	criteri.clear();
    }

    public void addCriterio(int criterio){
	Date curr=new Date(System.currentTimeMillis());
	int anno,mese;

	
	calendario.setTime(curr);
	switch(criterio){

	case(MESE_CORRENTE):
	    break;
	case(MESE_PREC):
	    calendario.add(Calendar.MONTH,-1);
	    break;
	case(MESE_PREC2):
	    calendario.add(Calendar.MONTH,-2);
	    break;
	case(MESE_PREC3):
	    calendario.add(Calendar.MONTH,-3);
	    break;
	}

	anno=calendario.get(Calendar.YEAR);
	mese=calendario.get(Calendar.MONTH);

	criteri.add(new Criterio(mese,anno));

    }

    public boolean test(DatiConnessione dato){
	long inizio,fine;
	boolean ris=false;
	Criterio criterio;
	int anno,mese;

	for (int i=0; i<criteri.size(); i++){
	    criterio=(Criterio)criteri.get(i);
	    anno=criterio.getAnno();
	    mese=criterio.getMese();

	 
	    calendario.set(Calendar.YEAR,anno);   
	    calendario.set(Calendar.MILLISECOND,0);
	    calendario.set(Calendar.SECOND,0);
	    calendario.set(Calendar.MINUTE,0);
	    calendario.set(Calendar.HOUR_OF_DAY,0);
	    calendario.set(Calendar.DAY_OF_MONTH,1);
	    calendario.set(Calendar.MONTH,mese);
	 
	    
	    inizio=calendario.getTime().getTime();
	    calendario.add(Calendar.MONTH,1);
	    fine = calendario.getTime().getTime();
	    
	    if ((dato.getInizio()>=inizio) && (dato.getInizio()<fine)){
		ris=true;
		break;
	    }
	}
	return ris;
    }


    public void addCriterioMese(String str){
	StringTokenizer token=new StringTokenizer(str,",");
	StringTokenizer token2;
	Criterio criterio;

	String t1=null,t2;

	int mese,anno;

	//	System.out.println("String in criterio: "+str);

	try {
	    while(token.hasMoreTokens()){
		token2=new StringTokenizer(t1=token.nextToken(),"-");
		mese=Integer.parseInt(t2=token2.nextToken());
		anno=Integer.parseInt(token2.nextToken());
		criterio=new Criterio(mese-1,anno);
		//		System.out.println(criterio);
		criteri.add(criterio);
	    }
	} catch (NoSuchElementException e){
	    System.err.println("Errore nel parsing di: "+t1);
	    System.exit(1);
	}
    }

    /*    public Selezionatore(Vector ar){
	this();
	dati=new ArrayList[ar.size()];
	ar.copyInto(dati);
	}*/


}


class Criterio {
    int mese;
    int anno;

    public Criterio(int mese, int anno) {
	this.mese=mese;
	this.anno=anno;
    }
    
    public int getAnno(){
	return anno;
    }

    public int getMese(){
	return mese;
    }

    public String toString(){
	return ("Criterio: mese: "+mese+" anno: "+anno);
    }

}


